==> tecfy_core_package-0.1.47.tar.gz: lib/views/components/entity/location_property.dart <==
part of tecfy_core_client_package;

class LocationPropertyComponenet extends StatefulWidget {
  final String initalValue;
  final String label;
  final bool isRequired;
  final bool readOnly;
  final void Function(String) onChanged;
  LocationPropertyComponenet(
      {this.initalValue,
      this.label,
      this.isRequired,
      this.onChanged,
      this.readOnly = false});
  @override
  _LocationPropertyComponenetState createState() =>
      _LocationPropertyComponenetState();
}

class _LocationPropertyComponenetState
    extends State<LocationPropertyComponenet> {
  GeoCoord point;
  String currentValue;
  @override
  initState() {
    print('------------------------------');
    print(widget.initalValue);
    currentValue = widget.initalValue;
    if (widget.initalValue == null || widget.initalValue.isEmpty) {
      point = null;
    } else {
      var p = widget.initalValue.split(',');
      if (p.length >= 1) {
        point = GeoCoord(double.parse(p[0]), double.parse(p[1]));
      }
    }
    if (point == null) {
      // get my location
    }
    super.initState();
  }

  onChanged() {
    var r = '${point.latitude},${point.longitude}';
    print('----------------------------- Selected Location is $r');
    setState(() => currentValue = r);
    widget.onChanged(r);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialButton(
        padding: EdgeInsets.all(0),
        onPressed: () async {
          var result = await showDialog(
              context: context, builder: (c) => LocationSelectPage(point));
          if (result != null) {
            point = result;
            onChanged();
          }
        },
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            SizedBox(height: 10),
            Text(
              '${widget.label ?? ''}${widget.isRequired ? '*' : ''}',
              style: ThemeService.labelStyle,
            ),
            Text(currentValue == null || currentValue.isEmpty
                ? '[Click To Select]'
                : currentValue),
            SizedBox(height: 10),
            Container(height: 1, color: ThemeService.textSubColor)
          ],
        ));
  }
}

class LocationSelectPage extends StatefulWidget {
  final GeoCoord location;
  LocationSelectPage(this.location);
  @override
  _LocationSelectPageState createState() => _LocationSelectPageState();
}

class _LocationSelectPageState extends State<LocationSelectPage> {
  String _mapStyle;
  GeoCoord point;
  GlobalKey<GoogleMapStateBase> _key = GlobalKey<GoogleMapStateBase>();

  @override
  initState() {
    point = widget.location;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Expanded(
            child: GoogleMap(
          key: _key,
          initialZoom: 17.5,
          initialPosition: point ?? GeoCoord(0, 0),
          mapType: MapType.hybrid,
          mapStyle: _mapStyle,
          interactive: true,
          markers: point == null
              ? null
              : {
                  Marker(point),
                },
          onTap: (coord) {
            point = coord;
            GoogleMap.of(_key).clearMarkers();
            GoogleMap.of(_key).addMarker(Marker(point));
          },
          mobilePreferences: const MobileMapPreferences(
              myLocationButtonEnabled: true,
              myLocationEnabled: true,
              mapToolbarEnabled: true,
              buildingsEnabled: true,
              compassEnabled: true,
              zoomGesturesEnabled: true,
              rotateGesturesEnabled: true,
              scrollGesturesEnabled: true,
              tiltGesturesEnabled: true,
              zoomControlsEnabled: true,
              trafficEnabled: false,
              padding: const EdgeInsets.all(0)),
          webPreferences: const WebMapPreferences(
            streetViewControl: true,
            fullscreenControl: true,
            mapTypeControl: true,
            panControl: true,
            overviewMapControl: true,
            rotateControl: true,
            scaleControl: true,
            zoomControl: true,
            dragGestures: true,
            scrollwheel: true,
          ),
        )),
        Row(children: [
          FlatButton(
              child: Text('OK'),
              onPressed: () {
                Navigator.pop(context, point);
              }),
          FlatButton(
              child: Text('Cancel'),
              onPressed: () {
                Navigator.pop(context);
              }),
        ])
      ],
    );
  }
}

==> tecfy_core_package-0.1.58.tar.gz: lib/views/components/entity/location_property.dart <==
part of tecfy_core_client_package;

class LocationPropertyComponenet extends StatefulWidget {
  final String initalValue;
  final String label;
  final bool isRequired;
  final bool readOnly;
  final void Function(String) onChanged;
  LocationPropertyComponenet(
      {this.initalValue,
      this.label,
      this.isRequired,
      this.onChanged,
      this.readOnly = false});
  @override
  _LocationPropertyComponenetState createState() =>
      _LocationPropertyComponenetState();
}

class _LocationPropertyComponenetState
    extends State<LocationPropertyComponenet> {
  LatLng point;
  String currentValue;
  @override
  initState() {
    print('------------------------------');
    print(widget.initalValue);
    currentValue = widget.initalValue;
    if (widget.initalValue == null || widget.initalValue.isEmpty) {
      point = null;
    } else {
      var p = widget.initalValue.split(',');
      if (p.length >= 1) {
        point = LatLng(double.parse(p[0]), double.parse(p[1]));
      }
    }
    if (point == null) {
      // get my location
    }
    super.initState();
  }

  onChanged() {
    var r = '${point.latitude},${point.longitude}';
    print('----------------------------- Selected Location is $r');
    setState(() => currentValue = r);
    widget.onChanged(r);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialButton(
        padding: EdgeInsets.all(0),
        onPressed: () async {
          var result = await showDialog(
              context: context, builder: (c) => LocationSelectPage(point));
          if (result != null) {
            point = result;
            onChanged();
          }
        },
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            SizedBox(height: 10),
            Text(
              '${widget.label ?? ''}${widget.isRequired ? '*' : ''}',
              style: ThemeService.labelStyle,
            ),
            Text(currentValue == null || currentValue.isEmpty
                ? '[Click To Select]'
                : currentValue),
            SizedBox(height: 10),
            Container(height: 1, color: ThemeService.textSubColor)
          ],
        ));
  }
}

class LocationSelectPage extends StatefulWidget {
  final LatLng location;
  LocationSelectPage(this.location);
  @override
  _LocationSelectPageState createState() => _LocationSelectPageState();
}

class _LocationSelectPageState extends State<LocationSelectPage> {
  String _mapStyle;
  LatLng point;
  GlobalKey _key = GlobalKey();
  GoogleMapController _controller;
  @override
  initState() {
    point = widget.location;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Expanded(
            child: GoogleMap(
          zoomControlsEnabled: true,
          onMapCreated: (c) => _controller = c,
          key: _key,
          initialCameraPosition: CameraPosition(zoom: 17.5, target: point),
          //initialPosition: point ?? GeoCoord(0, 0),
          mapType: MapType.hybrid,
          indoorViewEnabled: true,
          markers: point == null
              ? null
              : {
                  // Marker(point),
                },
          onTap: (coord) {
            point = coord;
            // _controller.getLatLng(screenCoordinate)
            // GoogleMap.of(_key).clearMarkers();
            // GoogleMap.of(_key).addMarker(Marker(point));
          },
        )),
        Row(children: [
          FlatButton(
              child: Text('OK'),
              onPressed: () {
                Navigator.pop(context, point);
              }),
          FlatButton(
              child: Text('Cancel'),
              onPressed: () {
                Navigator.pop(context);
              }),
        ])
      ],
    );
  }
}
